@@ -49,6 +49,7 @@
 #define  GRIB2_GTYPE_LATLON_ROTSTR         3  // Stretched and Rotated Latitude/longitude
 #define  GRIB2_GTYPE_STERE                20  // Polar stereographic projection
 #define  GRIB2_GTYPE_LCC                  30  // Lambert conformal
+#define  GRIB2_GTYPE_LLAM                 33  // Lambert LAM
 #define  GRIB2_GTYPE_GAUSSIAN             40  // Gaussian latitude/longitude
 #define  GRIB2_GTYPE_GAUSSIAN_ROT         41  // Rotated Gaussian latitude/longitude
 #define  GRIB2_GTYPE_GAUSSIAN_STR         42  // Stretched Gaussian latitude/longitude
@@ -56,6 +57,7 @@
 #define  GRIB2_GTYPE_SPECTRAL             50  // Spherical harmonic coefficients
 #define  GRIB2_GTYPE_GME                 100  // Triangular grid based on an icosahedron (GME)
 #define  GRIB2_GTYPE_UNSTRUCTURED        101  // General Unstructured Grid
+#define  GRIB2_GTYPE_HEALPIX             150  // HEALPix Grid
 
 const char *gribapiLibraryVersionString(void);
 void gribContainersNew(stream_t *streamptr);
@@ -69,7 +71,7 @@ void gribContainersDelete(stream_t *streamptr);
 #endif
 #endif
 
-static inline int have_gribapi_float_interface()
+static inline int have_gribapi_float_interface(void)
 {
 #ifdef HAVE_GRIBAPI_FLOAT_INTERFACE
   return 1;
