@@ -31,26 +31,26 @@ public:
   };
   inline static RegisterEntry<Mergegrid> registration = RegisterEntry<Mergegrid>(module);
 
-  CdoStreamID streamID1;
-  CdoStreamID streamID2;
-  CdoStreamID streamID3;
+  CdoStreamID streamID1{};
+  CdoStreamID streamID2{};
+  CdoStreamID streamID3{};
 
   int vlistID1{ CDI_UNDEFID };
   int vlistID2{ CDI_UNDEFID };
 
   int taxisID1{ CDI_UNDEFID };
-  int taxisID3;
+  int taxisID3{};
 
-  VarList varList1;
-  VarList varList2;
+  VarList varList1{};
+  VarList varList2{};
 
   Varray<double> array1;
   Varray<double> array2;
 
-  size_t gridsize1;
-  size_t gridsize2;
+  size_t gridsize1{};
+  size_t gridsize2{};
 
-  std::vector<long> gindex;
+  std::vector<long> gindex{};
 
 public:
   void
@@ -106,50 +106,50 @@ public:
   {
     int tsID = 0;
     while (true)
+    {
+      auto numFields = cdo_stream_inq_timestep(streamID1, tsID);
+      if (numFields == 0) break;
+
+      cdo_taxis_copy_timestep(taxisID3, taxisID1);
+
+      auto numFields2 = cdo_stream_inq_timestep(streamID2, tsID);
+      if (numFields2 == 0) cdo_abort("Input streams have different number of timesteps!");
+
+      if (numFields != numFields2) cdo_abort("Input streams have different number of fields!");
+
+      cdo_def_timestep(streamID3, tsID);
+
+      while (numFields-- > 0)
       {
-        auto numFields = cdo_stream_inq_timestep(streamID1, tsID);
-        if (numFields == 0) break;
+        (void) cdo_inq_field(streamID2);
+        size_t numMissVals2;
+        cdo_read_field(streamID2, array2.data(), &numMissVals2);
 
-        cdo_taxis_copy_timestep(taxisID3, taxisID1);
+        auto [varID, levelID] = cdo_inq_field(streamID1);
+        size_t numMissVals1;
+        cdo_read_field(streamID1, array1.data(), &numMissVals1);
 
-        auto numFields2 = cdo_stream_inq_timestep(streamID2, tsID);
-        if (numFields2 == 0) cdo_abort("Input streams have different number of timesteps!");
+        auto missval1 = varList1.vars[varID].missval;
+        auto missval2 = varList2.vars[varID].missval;
 
-        if (numFields != numFields2) cdo_abort("Input streams have different number of fields!");
+        for (size_t i = 0; i < gridsize2; ++i)
+        {
+          if (gindex[i] >= 0 && fp_is_not_equal(array2[i], missval2)) { array1[gindex[i]] = array2[i]; }
+        }
 
-        cdo_def_timestep(streamID3, tsID);
+        if (numMissVals1)
+        {
+          numMissVals1 = 0;
+          for (size_t i = 0; i < gridsize1; ++i)
+            if (fp_is_equal(array1[i], missval1)) numMissVals1++;
+        }
 
-        while (numFields-- > 0)
-          {
-            (void) cdo_inq_field(streamID2);
-            size_t numMissVals2;
-            cdo_read_field(streamID2, array2.data(), &numMissVals2);
-
-            auto [varID, levelID] = cdo_inq_field(streamID1);
-            size_t numMissVals1;
-            cdo_read_field(streamID1, array1.data(), &numMissVals1);
-
-            auto missval1 = varList1.vars[varID].missval;
-            auto missval2 = varList2.vars[varID].missval;
-
-            for (size_t i = 0; i < gridsize2; ++i)
-              {
-                if (gindex[i] >= 0 && fp_is_not_equal(array2[i], missval2)) { array1[gindex[i]] = array2[i]; }
-              }
-
-            if (numMissVals1)
-              {
-                numMissVals1 = 0;
-                for (size_t i = 0; i < gridsize1; ++i)
-                  if (fp_is_equal(array1[i], missval1)) numMissVals1++;
-              }
-
-            cdo_def_field(streamID3, varID, levelID);
-            cdo_write_field(streamID3, array1.data(), numMissVals1);
-          }
-
-        tsID++;
+        cdo_def_field(streamID3, varID, levelID);
+        cdo_write_field(streamID3, array1.data(), numMissVals1);
       }
+
+      tsID++;
+    }
   }
 
   void
