@@ -40,19 +40,20 @@ public:
   };
   inline static RegisterEntry<Pressure> registration = RegisterEntry<Pressure>(module);
 
-  int PRESSURE_FULL, PRESSURE_HALF, DELTA_PRESSURE;
+private:
+  int PRESSURE_FULL{}, PRESSURE_HALF{}, DELTA_PRESSURE{};
 
-  CdoStreamID streamID1;
-  CdoStreamID streamID2;
+  CdoStreamID streamID1{};
+  CdoStreamID streamID2{};
 
   int taxisID1{ CDI_UNDEFID };
   int taxisID2{ CDI_UNDEFID };
 
-  int pvarID;
+  int pvarID{};
 
-  int operatorID;
+  int operatorID{};
 
-  size_t gridsize;
+  size_t gridsize{};
   int zaxisID_ML = -1;
 
   VarIDs varIDs;
@@ -99,66 +100,66 @@ public:
     int zaxisID_PL = -1;
     int zaxisType = -1;
     if (operatorID == PRESSURE_FULL || operatorID == DELTA_PRESSURE)
+    {
+      if (numFullLevels == numHybridLevels)
+        zaxisID_PL = zaxisID_ML;
+      else
       {
-        if (numFullLevels == numHybridLevels)
-          zaxisID_PL = zaxisID_ML;
-        else
-          {
-            if (Options::cdoVerbose) cdo_print("Creating ZAXIS_HYBRID .. (numFullLevels=%d)", numFullLevels);
-            zaxisType = ZAXIS_HYBRID;
-            numHybridLevels = numFullLevels;
-          }
+        if (Options::cdoVerbose) cdo_print("Creating ZAXIS_HYBRID .. (numFullLevels=%d)", numFullLevels);
+        zaxisType = ZAXIS_HYBRID;
+        numHybridLevels = numFullLevels;
       }
+    }
     else
+    {
+      if (numHalfLevels == numHybridLevels)
+        zaxisID_PL = zaxisID_ML;
+      else
       {
-        if (numHalfLevels == numHybridLevels)
-          zaxisID_PL = zaxisID_ML;
-        else
-          {
-            if (Options::cdoVerbose) cdo_print("Creating ZAXIS_HYBRID_HALF .. (numHalfLevels=%d)", numHalfLevels);
-            zaxisType = ZAXIS_HYBRID_HALF;
-            numHybridLevels = numHalfLevels;
-          }
+        if (Options::cdoVerbose) cdo_print("Creating ZAXIS_HYBRID_HALF .. (numHalfLevels=%d)", numHalfLevels);
+        zaxisType = ZAXIS_HYBRID_HALF;
+        numHybridLevels = numHalfLevels;
       }
+    }
 
     if (zaxisID_PL == -1)
-      {
-        zaxisID_PL = zaxisCreate(zaxisType, numHybridLevels);
+    {
+      zaxisID_PL = zaxisCreate(zaxisType, numHybridLevels);
 
-        Varray<double> level(numHalfLevels);
-        for (int l = 0; l < numHalfLevels; ++l) level[l] = l + 1;
-        zaxisDefLevels(zaxisID_PL, level.data());
-        zaxisDefVct(zaxisID_PL, 2 * numHalfLevels, vct.data());
-      }
+      Varray<double> level(numHalfLevels);
+      for (int l = 0; l < numHalfLevels; ++l) level[l] = l + 1;
+      zaxisDefLevels(zaxisID_PL, level.data());
+      zaxisDefVct(zaxisID_PL, 2 * numHalfLevels, vct.data());
+    }
 
     varIDs = varList_search_varIDs(varList1, numFullLevels);
 
     if (Options::cdoVerbose)
-      {
-        cdo_print("Found:");
-        // clang-format off
-        if (-1 != varIDs.psID)   cdo_print("  %s -> %s", var_stdname(surface_air_pressure), varList1.vars[varIDs.psID].name);
-        if (-1 != varIDs.lnpsID) cdo_print("  LOG(%s) -> %s", var_stdname(surface_air_pressure), varList1.vars[varIDs.lnpsID].name);
-        // clang-format on
-      }
+    {
+      cdo_print("Found:");
+      // clang-format off
+      if (-1 != varIDs.psID)   cdo_print("  %s -> %s", var_stdname(surface_air_pressure), varList1.vars[varIDs.psID].name);
+      if (-1 != varIDs.lnpsID) cdo_print("  LOG(%s) -> %s", var_stdname(surface_air_pressure), varList1.vars[varIDs.lnpsID].name);
+      // clang-format on
+    }
 
     pvarID = varIDs.lnpsID;
     if (zaxisID_ML != -1 && varIDs.lnpsID != -1)
+    {
+      auto gridType = varList1.vars[varIDs.lnpsID].gridType;
+      if (gridType == GRID_SPECTRAL)
       {
-        auto gridType = varList1.vars[varIDs.lnpsID].gridType;
-        if (gridType == GRID_SPECTRAL)
-          {
-            varIDs.lnpsID = -1;
-            cdo_warning("Spectral LOG(%s) not supported - using %s!", var_stdname(surface_air_pressure),
-                        var_stdname(surface_air_pressure));
-          }
+        varIDs.lnpsID = -1;
+        cdo_warning("Spectral LOG(%s) not supported - using %s!", var_stdname(surface_air_pressure),
+                    var_stdname(surface_air_pressure));
       }
+    }
 
     if (zaxisID_ML != -1 && varIDs.lnpsID == -1)
-      {
-        pvarID = varIDs.psID;
-        if (varIDs.psID == -1) cdo_abort("%s not found!", var_stdname(surface_air_pressure));
-      }
+    {
+      pvarID = varIDs.psID;
+      if (varIDs.psID == -1) cdo_abort("%s not found!", var_stdname(surface_air_pressure));
+    }
 
     auto gridID = varList1.vars[pvarID].gridID;
     if (gridInqType(gridID) == GRID_SPECTRAL)
@@ -167,7 +168,7 @@ public:
     array = Varray<double>(gridsize);
 
     auto vlistID2 = vlistCreate();
-    vlistDefNtsteps(vlistID2, vlistNtsteps(vlistID1));
+    vlistDefNtsteps(vlistID2, varList1.numSteps());
 
     auto ovarID = vlistDefVar(vlistID2, gridID, zaxisID_PL, TIME_VARYING);
     vlistDefVarParam(vlistID2, ovarID, cdiEncodeParam(1, 255, 255));
@@ -188,69 +189,69 @@ public:
   {
     int tsID = 0;
     while (true)
+    {
+      auto numFields = cdo_stream_inq_timestep(streamID1, tsID);
+      if (numFields == 0) break;
+
+      cdo_taxis_copy_timestep(taxisID2, taxisID1);
+      cdo_def_timestep(streamID2, tsID);
+
+      for (int fieldID = 0; fieldID < numFields; ++fieldID)
       {
-        auto numFields = cdo_stream_inq_timestep(streamID1, tsID);
-        if (numFields == 0) break;
-
-        cdo_taxis_copy_timestep(taxisID2, taxisID1);
-        cdo_def_timestep(streamID2, tsID);
-
-        for (int fieldID = 0; fieldID < numFields; ++fieldID)
-          {
-            auto [varID, levelID] = cdo_inq_field(streamID1);
-            if (varID == pvarID)
-              {
-                size_t numMissVals;
-                cdo_read_field(streamID1, array.data(), &numMissVals);
-                if (numMissVals) cdo_abort("Missing valus unsupported!");
-              }
-          }
-
-        if (zaxisID_ML != -1)
-          {
-            if (varIDs.lnpsID != -1)
-              for (size_t i = 0; i < gridsize; ++i) psProg[i] = std::exp(array[i]);
-            else if (varIDs.psID != -1)
-              varray_copy(gridsize, array, psProg);
-
-            // check range of psProg
-            auto mm = varray_min_max(psProg);
-            if (mm.min < MIN_PS || mm.max > MAX_PS) cdo_warning("Surface pressure out of range (min=%g max=%g)!", mm.min, mm.max);
-
-            vct_to_hybrid_pressure(pressureFull.data(), pressureHalf.data(), vct, psProg.data(), numFullLevels, gridsize);
-          }
-
-        double *pout = nullptr;
-        int nlevels = 0;
-        if (operatorID == PRESSURE_FULL)
-          {
-            nlevels = numFullLevels;
-            pout = pressureFull.data();
-          }
-        else if (operatorID == DELTA_PRESSURE)
-          {
-            nlevels = numFullLevels;
-            for (int k = 0; k < numFullLevels; ++k)
-              for (size_t i = 0; i < gridsize; ++i)
-                deltaPressure[k * gridsize + i] = pressureHalf[(k + 1) * gridsize + i] - pressureHalf[k * gridsize + i];
-
-            pout = deltaPressure.data();
-          }
-        else if (operatorID == PRESSURE_HALF)
-          {
-            nlevels = numHalfLevels;
-            pout = pressureHalf.data();
-          }
-
-        int varID = 0;
-        for (int levelID = 0; levelID < nlevels; ++levelID)
-          {
-            cdo_def_field(streamID2, varID, levelID);
-            cdo_write_field(streamID2, &pout[levelID * gridsize], 0);
-          }
-
-        tsID++;
+        auto [varID, levelID] = cdo_inq_field(streamID1);
+        if (varID == pvarID)
+        {
+          size_t numMissVals;
+          cdo_read_field(streamID1, array.data(), &numMissVals);
+          if (numMissVals) cdo_abort("Missing valus unsupported!");
+        }
       }
+
+      if (zaxisID_ML != -1)
+      {
+        if (varIDs.lnpsID != -1)
+          for (size_t i = 0; i < gridsize; ++i) psProg[i] = std::exp(array[i]);
+        else if (varIDs.psID != -1)
+          varray_copy(gridsize, array, psProg);
+
+        // check range of psProg
+        auto mm = varray_min_max(psProg);
+        if (mm.min < MIN_PS || mm.max > MAX_PS) cdo_warning("Surface pressure out of range (min=%g max=%g)!", mm.min, mm.max);
+
+        vct_to_hybrid_pressure(pressureFull.data(), pressureHalf.data(), vct, psProg.data(), numFullLevels, gridsize);
+      }
+
+      double *pout = nullptr;
+      int nlevels = 0;
+      if (operatorID == PRESSURE_FULL)
+      {
+        nlevels = numFullLevels;
+        pout = pressureFull.data();
+      }
+      else if (operatorID == DELTA_PRESSURE)
+      {
+        nlevels = numFullLevels;
+        for (int k = 0; k < numFullLevels; ++k)
+          for (size_t i = 0; i < gridsize; ++i)
+            deltaPressure[k * gridsize + i] = pressureHalf[(k + 1) * gridsize + i] - pressureHalf[k * gridsize + i];
+
+        pout = deltaPressure.data();
+      }
+      else if (operatorID == PRESSURE_HALF)
+      {
+        nlevels = numHalfLevels;
+        pout = pressureHalf.data();
+      }
+
+      int varID = 0;
+      for (int levelID = 0; levelID < nlevels; ++levelID)
+      {
+        cdo_def_field(streamID2, varID, levelID);
+        cdo_write_field(streamID2, &pout[levelID * gridsize], 0);
+      }
+
+      tsID++;
+    }
   }
 
   void
