@@ -52,10 +52,10 @@ cropData(double *array1, int gridID1, double *array2, int gridID2, int subI0, in
 
   long array2Idx = 0;
   for (long ilat1 = subJ0; ilat1 <= subJ1; ilat1++)  // copy the last row as well..
-    {
-      array_copy(rowLen, &array1[ilat1 * nlon1 + subI0], &array2[array2Idx]);
-      array2Idx += rowLen;
-    }
+  {
+    array_copy(rowLen, &array1[ilat1 * nlon1 + subI0], &array2[array2Idx]);
+    array2Idx += rowLen;
+  }
 }
 
 class Samplegrid : public Process
@@ -73,7 +73,7 @@ public:
   };
   inline static RegisterEntry<Samplegrid> registration = RegisterEntry<Samplegrid>(module);
 
-  int SAMPLEGRID, SUBGRID;
+  int SAMPLEGRID{}, SUBGRID{};
   int resampleFactor = 0;
   int subI0 = 0, subI1 = 0, subJ0 = 0, subJ1 = 0;
   struct sbox_t
@@ -81,22 +81,22 @@ public:
     int gridSrcID, gridIDsampled;
   };
 
-  CdoStreamID streamID1;
-  CdoStreamID streamID2;
+  CdoStreamID streamID1{};
+  CdoStreamID streamID2{};
 
   int vlistID1{ CDI_UNDEFID };
   int vlistID2{ CDI_UNDEFID };
 
-  VarList varList1;
-  VarList varList2;
+  VarList varList1{};
+  VarList varList2{};
 
   int taxisID1{ CDI_UNDEFID };
   int taxisID2{ CDI_UNDEFID };
 
   std::vector<bool> vars;
 
-  int operatorID;
-  int numGrids;
+  int operatorID{};
+  int numGrids{};
   std::vector<sbox_t> sbox;
 
 public:
@@ -111,24 +111,24 @@ public:
     auto nch = cdo_operator_argc();
 
     if (operatorID == SAMPLEGRID)
-      {
-        Debug(cdoDebugExt, "samplegrid operator requested..");
-        if (nch < 1) cdo_abort("Number of input arguments < 1; At least 1 argument needed: resample-factor (2,3,4, .. etc)");
-        resampleFactor = parameter_to_int(cdo_operator_argv(0));
+    {
+      Debug(cdoDebugExt, "samplegrid operator requested..");
+      if (nch < 1) cdo_abort("Number of input arguments < 1; At least 1 argument needed: resample-factor (2,3,4, .. etc)");
+      resampleFactor = parameter_to_int(cdo_operator_argv(0));
 
-        Debug(cdoDebugExt, "resampleFactor = %d", resampleFactor);
-      }
+      Debug(cdoDebugExt, "resampleFactor = %d", resampleFactor);
+    }
     else if (operatorID == SUBGRID)
-      {
-        Debug(cdoDebugExt, "subgrid operator requested..");
-        if (nch < 4)
-          cdo_abort("Number of input arguments < 4; Must specify sub-grid indices: i0,i1,j0,j1; This works only with LCC grid."
-                    " For other grids use: selindexbox");
-        subI0 = parameter_to_int(cdo_operator_argv(0));
-        subI1 = parameter_to_int(cdo_operator_argv(1));
-        subJ0 = parameter_to_int(cdo_operator_argv(2));
-        subJ1 = parameter_to_int(cdo_operator_argv(3));
-      }
+    {
+      Debug(cdoDebugExt, "subgrid operator requested..");
+      if (nch < 4)
+        cdo_abort("Number of input arguments < 4; Must specify sub-grid indices: i0,i1,j0,j1; This works only with LCC grid."
+                  " For other grids use: selindexbox");
+      subI0 = parameter_to_int(cdo_operator_argv(0));
+      subI1 = parameter_to_int(cdo_operator_argv(1));
+      subJ0 = parameter_to_int(cdo_operator_argv(2));
+      subJ1 = parameter_to_int(cdo_operator_argv(3));
+    }
     else
       cdo_abort("Unknown operator ...");
 
@@ -152,36 +152,38 @@ public:
     sbox = std::vector<sbox_t>(numGrids);
 
     for (int index = 0; index < numGrids; ++index)
-      {
-        const auto gridSrcID = vlistGrid(vlistID1, index);
-        int gridIDsampled = -1;
+    {
+      const auto gridSrcID = vlistGrid(vlistID1, index);
+      int gridIDsampled = -1;
 
-        if (gridInqSize(gridSrcID) <= 1) continue;
+      if (gridInqSize(gridSrcID) <= 1) continue;
 
-        int gridtype = gridInqType(gridSrcID);
-        if (!(gridtype == GRID_GAUSSIAN || gridtype == GRID_LONLAT || gridtype == GRID_PROJECTION || gridtype == GRID_CURVILINEAR
-              || gridtype == GRID_GENERIC))
-          cdo_abort("Unsupported gridtype: %s", gridNamePtr(gridtype));
+      int gridtype = gridInqType(gridSrcID);
+      if (!(gridtype == GRID_GAUSSIAN || gridtype == GRID_LONLAT || gridtype == GRID_PROJECTION || gridtype == GRID_CURVILINEAR
+            || gridtype == GRID_GENERIC))
+        cdo_abort("Unsupported gridtype: %s", gridNamePtr(gridtype));
 
-        if (operatorID == SAMPLEGRID) { gridIDsampled = cdo_define_sample_grid(gridSrcID, resampleFactor); }
-        else if (operatorID == SUBGRID) { gridIDsampled = cdo_define_subgrid_grid(gridSrcID, subI0, subI1, subJ0, subJ1); }
+      if (operatorID == SAMPLEGRID) { gridIDsampled = cdo_define_sample_grid(gridSrcID, resampleFactor); }
+      else if (operatorID == SUBGRID) { gridIDsampled = cdo_define_subgrid_grid(gridSrcID, subI0, subI1, subJ0, subJ1); }
 
-        sbox[index].gridSrcID = gridSrcID;
-        sbox[index].gridIDsampled = gridIDsampled;
+      sbox[index].gridSrcID = gridSrcID;
+      sbox[index].gridIDsampled = gridIDsampled;
 
-        // if ( cdoDebugExt>=10 ) cdo_print_griddes(gridSrcID, 1);
-        // if ( cdoDebugExt>=10 ) cdo_print_griddes(gridIDsampled, 1);
+      // if ( cdoDebugExt>=10 ) cdo_print_griddes(gridSrcID, 1);
+      // if ( cdoDebugExt>=10 ) cdo_print_griddes(gridIDsampled, 1);
 
-        vlistChangeGridIndex(vlistID2, index, gridIDsampled);
+      vlistChangeGridIndex(vlistID2, index, gridIDsampled);
 
-        for (auto const &var : varList1.vars)
-          if (gridSrcID == var.gridID) vars[var.ID] = true;
-      }
+      for (auto const &var : varList1.vars)
+        if (gridSrcID == var.gridID) vars[var.ID] = true;
+    }
 
-    Debug(cdoDebugExt, [&]() {
-      if (operatorID == SAMPLEGRID) Debug("Resampled grid has been created.");
-      if (operatorID == SUBGRID) Debug("Sub-grid has been created.");
-    });
+    Debug(cdoDebugExt,
+          [&]()
+          {
+            if (operatorID == SAMPLEGRID) Debug("Resampled grid has been created.");
+            if (operatorID == SUBGRID) Debug("Sub-grid has been created.");
+          });
 
     varList2 = VarList(vlistID2);
 
@@ -202,54 +204,51 @@ public:
 
     int tsID = 0;
     while (true)
+    {
+      auto numFields = cdo_stream_inq_timestep(streamID1, tsID);
+      if (numFields == 0) break;
+
+      cdo_taxis_copy_timestep(taxisID2, taxisID1);
+      cdo_def_timestep(streamID2, tsID);
+
+      for (int fieldID = 0; fieldID < numFields; ++fieldID)
       {
-        auto numFields = cdo_stream_inq_timestep(streamID1, tsID);
-        if (numFields == 0) break;
+        auto [varID, levelID] = cdo_inq_field(streamID1);
+        size_t numMissVals;
+        cdo_read_field(streamID1, array1.data(), &numMissVals);
 
-        cdo_taxis_copy_timestep(taxisID2, taxisID1);
-        cdo_def_timestep(streamID2, tsID);
+        cdo_def_field(streamID2, varID, levelID);
 
-        for (int fieldID = 0; fieldID < numFields; ++fieldID)
+        Debug(cdoDebugExt >= 20, "Processing field (%d) of %d.", fieldID, numFields);
+
+        if (vars[varID])
+        {
+          auto gridSrcID = varList1.vars[varID].gridID;
+
+          int index;
+          for (index = 0; index < numGrids; ++index)
+            if (gridSrcID == sbox[index].gridSrcID) break;
+
+          if (index == numGrids) cdo_abort("Internal problem, grid not found!");
+
+          int gridIDsampled = sbox[index].gridIDsampled;
+          gridsize2Max = gridInqSize(gridIDsampled);
+
+          if (operatorID == SAMPLEGRID) { sampleData(array1.data(), gridSrcID, array2.data(), gridIDsampled, resampleFactor); }
+          else if (operatorID == SUBGRID)
           {
-            auto [varID, levelID] = cdo_inq_field(streamID1);
-            size_t numMissVals;
-            cdo_read_field(streamID1, array1.data(), &numMissVals);
-
-            cdo_def_field(streamID2, varID, levelID);
-
-            Debug(cdoDebugExt >= 20, "Processing field (%d) of %d.", fieldID, numFields);
-
-            if (vars[varID])
-              {
-                auto gridSrcID = varList1.vars[varID].gridID;
-
-                int index;
-                for (index = 0; index < numGrids; ++index)
-                  if (gridSrcID == sbox[index].gridSrcID) break;
-
-                if (index == numGrids) cdo_abort("Internal problem, grid not found!");
-
-                int gridIDsampled = sbox[index].gridIDsampled;
-                gridsize2Max = gridInqSize(gridIDsampled);
-
-                if (operatorID == SAMPLEGRID)
-                  {
-                    sampleData(array1.data(), gridSrcID, array2.data(), gridIDsampled, resampleFactor);
-                  }
-                else if (operatorID == SUBGRID)
-                  {
-                    cropData(array1.data(), gridSrcID, array2.data(), gridIDsampled, subI0, subI1, subJ0, subJ1);
-                  }
-
-                if (numMissVals) { numMissVals = varray_num_mv(gridsize2Max, array2, varList2.vars[varID].missval); }
-
-                cdo_write_field(streamID2, array2.data(), numMissVals);
-              }
-            else { cdo_write_field(streamID2, array1.data(), numMissVals); }
+            cropData(array1.data(), gridSrcID, array2.data(), gridIDsampled, subI0, subI1, subJ0, subJ1);
           }
 
-        tsID++;
+          if (numMissVals) { numMissVals = varray_num_mv(gridsize2Max, array2, varList2.vars[varID].missval); }
+
+          cdo_write_field(streamID2, array2.data(), numMissVals);
+        }
+        else { cdo_write_field(streamID2, array1.data(), numMissVals); }
       }
+
+      tsID++;
+    }
   }
 
   void
