@@ -28,10 +28,10 @@ tstepcount(long nts, T missval, Varray<T> const &v, T refval)
   long j;
   long n = 0;
   for (j = 0; j < nts; ++j)
-    {
-      n++;
-      if (fp_is_equal(v[j], refval)) break;
-    }
+  {
+    n++;
+    if (fp_is_equal(v[j], refval)) break;
+  }
 
   return (j == nts) ? missval : (T) n;
 }
@@ -52,17 +52,17 @@ public:
 
   CdiDateTime vDateTime{};
 
-  CdoStreamID streamID1;
-  CdoStreamID streamID2;
+  CdoStreamID streamID1{};
+  CdoStreamID streamID2{};
 
   int vlistID1{ CDI_UNDEFID };
   int taxisID1{ CDI_UNDEFID };
   int taxisID2{ CDI_UNDEFID };
 
-  int numVars;
-  double refval;
+  int numVars{};
+  double refval{};
 
-  VarList varList1;
+  VarList varList1{};
   FieldVector3D varsData;
 
 public:
@@ -78,7 +78,9 @@ public:
 
     vlistDefNtsteps(vlistID2, 1);
 
-    numVars = vlistNvars(vlistID1);
+    varList1 = VarList(vlistID1);
+
+    numVars = varList1.numVars();
     for (int varID = 0; varID < numVars; ++varID) cdiDefKeyString(vlistID2, varID, CDI_KEY_UNITS, "steps");
 
     taxisID1 = vlistInqTaxis(vlistID1);
@@ -87,8 +89,6 @@ public:
 
     streamID2 = cdo_open_write(1);
     cdo_def_vlist(streamID2, vlistID2);
-
-    varList1 = VarList(vlistID1);
   }
 
   void
@@ -96,84 +96,84 @@ public:
   {
     int tsID = 0;
     while (true)
+    {
+      auto numFields = cdo_stream_inq_timestep(streamID1, tsID);
+      if (numFields == 0) break;
+
+      constexpr size_t NALLOC_INC = 1024;
+      if ((size_t) tsID >= varsData.size()) varsData.resize(varsData.size() + NALLOC_INC);
+
+      vDateTime = taxisInqVdatetime(taxisID1);
+
+      field2D_init(varsData[tsID], varList1);
+
+      for (int fieldID = 0; fieldID < numFields; ++fieldID)
       {
-        auto numFields = cdo_stream_inq_timestep(streamID1, tsID);
-        if (numFields == 0) break;
-
-        constexpr size_t NALLOC_INC = 1024;
-        if ((size_t) tsID >= varsData.size()) varsData.resize(varsData.size() + NALLOC_INC);
-
-        vDateTime = taxisInqVdatetime(taxisID1);
-
-        field2D_init(varsData[tsID], varList1);
-
-        for (int fieldID = 0; fieldID < numFields; ++fieldID)
-          {
-            auto [varID, levelID] = cdo_inq_field(streamID1);
-            auto &field = varsData[tsID][varID][levelID];
-            field.init(varList1.vars[varID]);
-            cdo_read_field(streamID1, field);
-          }
-
-        tsID++;
+        auto [varID, levelID] = cdo_inq_field(streamID1);
+        auto &field = varsData[tsID][varID][levelID];
+        field.init(varList1.vars[varID]);
+        cdo_read_field(streamID1, field);
       }
 
+      tsID++;
+    }
+
     int nts = tsID;
 
     std::vector<Field> fields(Threading::ompNumMaxThreads);
 
     for (int varID = 0; varID < numVars; ++varID)
+    {
+      auto const &var1 = varList1.vars[varID];
+      auto memType = var1.memType;
+      auto missval = var1.missval;
+      auto gridsize = var1.gridsize;
+      for (int levelID = 0; levelID < var1.nlevels; ++levelID)
       {
-        auto const &var1 = varList1.vars[varID];
-        auto memType = var1.memType;
-        auto missval = var1.missval;
-        auto gridsize = var1.gridsize;
-        for (int levelID = 0; levelID < var1.nlevels; ++levelID)
-          {
 #ifdef _OPENMP
 #pragma omp parallel for default(shared) schedule(dynamic, 1)
 #endif
-            for (size_t i = 0; i < gridsize; ++i)
-              {
-                auto ompthID = cdo_omp_get_thread_num();
+        for (size_t i = 0; i < gridsize; ++i)
+        {
+          auto ompthID = cdo_omp_get_thread_num();
 
-                if (memType == MemType::Float)
-                  {
-                    auto &v = fields[ompthID].vec_f;
-                    v.resize(nts);
-                    for (int t = 0; t < nts; ++t) v[t] = varsData[t][varID][levelID].vec_f[i];
+          if (memType == MemType::Float)
+          {
+            auto &v = fields[ompthID].vec_f;
+            v.resize(nts);
+            for (int t = 0; t < nts; ++t) v[t] = varsData[t][varID][levelID].vec_f[i];
 
-                    auto count = tstepcount(nts, (float) missval, v, (float) refval);
+            auto count = tstepcount(nts, (float) missval, v, (float) refval);
 
-                    varsData[0][varID][levelID].vec_f[i] = count;
-                  }
-                else
-                  {
-                    auto &v = fields[ompthID].vec_d;
-                    v.resize(nts);
-                    for (int t = 0; t < nts; ++t) v[t] = varsData[t][varID][levelID].vec_d[i];
-
-                    auto count = tstepcount(nts, missval, v, refval);
-
-                    varsData[0][varID][levelID].vec_d[i] = count;
-                  }
-              }
+            varsData[0][varID][levelID].vec_f[i] = count;
           }
+          else
+          {
+            auto &v = fields[ompthID].vec_d;
+            v.resize(nts);
+            for (int t = 0; t < nts; ++t) v[t] = varsData[t][varID][levelID].vec_d[i];
+
+            auto count = tstepcount(nts, missval, v, refval);
+
+            varsData[0][varID][levelID].vec_d[i] = count;
+          }
+        }
       }
+    }
 
     taxisDefVdatetime(taxisID2, vDateTime);
     cdo_def_timestep(streamID2, 0);
 
     for (int varID = 0; varID < numVars; ++varID)
+    {
+      for (int levelID = 0; levelID < varList1.vars[varID].nlevels; ++levelID)
       {
-        for (int levelID = 0; levelID < varList1.vars[varID].nlevels; ++levelID)
-          {
-            cdo_def_field(streamID2, varID, levelID);
-            auto &field1 = varsData[0][varID][levelID];
-            field_num_mv(field1);
-            cdo_write_field(streamID2, field1);
-          }
+        cdo_def_field(streamID2, varID, levelID);
+        auto &field1 = varsData[0][varID][levelID];
+        field_num_mv(field1);
+        cdo_write_field(streamID2, field1);
       }
+    }
   }
 
   void
