@@ -3,6 +3,7 @@
 
 #include <vector>
 #include <string>
+#include "mpim_grid/grid_options.h"
 
 #ifdef HAVE_CONFIG_H
 #include "config.h" /* _FILE_OFFSET_BITS influence off_t */
@@ -14,16 +15,14 @@
 namespace cdo
 {
 extern const char *progname;
-extern char File_Suffix[32];
 extern const char *Version;
-extern std::string DownloadPath;
-extern std::string IconGrids;
+extern std::string FileSuffix;
 extern bool stdinIsTerminal;
 extern bool stdoutIsTerminal;
 extern bool stderrIsTerminal;
 }  // namespace cdo
 
-enum class MemType
+enum struct MemType
 {
   Native,
   Float,
@@ -38,6 +37,8 @@ extern int nsb;  // Number of significant bits
 extern bool benchmark;
 extern bool silentMode;
 extern bool test;
+extern bool fast;
+extern bool lazyGridLoad;
 extern bool force;
 
 extern std::string filterSpec;
@@ -48,6 +49,7 @@ extern int cdoCompType;
 extern int cdoCompLevel;
 extern bool cdoInteractive;
 extern bool cdoVerbose;
+extern int CDO_Rusage;
 extern bool cdoProcessInfo;
 extern int cdoExitStatus;
 extern bool Timer;
@@ -65,22 +67,28 @@ extern bool cdoDiag;
 
 extern MemType CDO_Memtype;
 
-extern bool CDO_Parallel_Read;
+extern bool CDO_Async_Read;
 extern bool CDO_task;
 
 extern int CDO_Reduce_Dim;
 extern int CDO_Append_History;
 extern bool CDO_Reset_History;
+extern bool PrintFilename;
 
 extern unsigned Random_Seed;
 
 extern int cdoChunkType;
 extern int cdoChunkSize;
+extern int cdoChunkSizeDimT;
+extern int cdoChunkSizeDimZ;
+extern int cdoChunkSizeDimY;
+extern int cdoChunkSizeDimX;
 extern bool cdoOverwriteMode;
 extern bool cdoParIO;
 extern bool cdoRegulargrid;
-size_t cdo_num_varnames();
+extern std::string cdoQueryParameter;
 extern std::vector<std::string> cdoVarnames;
+size_t cdo_num_varnames();
 
 extern bool REMAP_genweights;
 
@@ -88,7 +96,8 @@ extern bool REMAP_genweights;
 
 namespace Threading
 {
-extern int ompNumThreads;
+extern int ompNumMaxThreads;
+extern int ompNumUserRequestedThreads;
 extern bool cdoLockIO;
 }  // namespace Threading
 
