@@ -14,18 +14,20 @@
 #include <pthread.h>
 #endif
 
+#ifdef HAVE_NETCDF
+#include <netcdf.h>
+#include <netcdf_mem.h>
+#endif
+
 #ifdef _OPENMP
 #include <omp.h>
 #endif
 
-#include <stdio.h>
-#include <iostream>
+#include <cstdio>
 #include <string>
 #include <sstream>
 
 #include "process.h"
-#include "cdo_timer.h"
-#include "util_string.h"
 #include "cdo_options.h"
 #include "fileStream.h"
 #include "pipeStream.h"
@@ -48,7 +50,7 @@ set_process_num(int p_num)
 }
 
 std::string
-Process::replace_alias(const std::string &p_calledBy, const CdoModule &p_module)
+Process::replace_alias(std::string const &p_calledBy, const CdoModule &p_module)
 {
   std::string originalName = p_calledBy;
   int aliasID = p_module.is_alias(p_calledBy);
@@ -56,7 +58,7 @@ Process::replace_alias(const std::string &p_calledBy, const CdoModule &p_module)
   return originalName;
 }
 
-Process::Process(int p_ID, const std::string &p_operatorName, const std::vector<std::string> &p_arguments,
+Process::Process(int p_ID, std::string const &p_operatorName, std::vector<std::string> const &p_arguments,
                  const CdoModule &p_module)
     : arguments(p_module.arguments), m_ID(p_ID), m_module(p_module), m_oargv(p_arguments)
 {
@@ -81,7 +83,7 @@ Process::get_stream_cnt_out()
 }
 
 void
-Process::def_prompt(const std::string &name)
+Process::def_prompt(std::string const &name)
 {
   if (m_ID == 0)
     std::snprintf(prompt, sizeof(prompt), "%s    %s", cdo::progname, name.c_str());
@@ -102,10 +104,10 @@ Process::get_operator_id()
 
   Debug(PROCESS, "searching for %s", operatorName);
   for (size_t operID = 0; operID < m_module.operators.size(); operID++)
-    {
-      Debug(PROCESS, "comparing  %s and %s", operatorName, m_module.operators[operID].name);
-      if (operatorName == m_module.operators[operID].name) return operID;
-    }
+  {
+    Debug(PROCESS, "comparing  %s and %s", operatorName, m_module.operators[operID].name);
+    if (operatorName == m_module.operators[operID].name) return operID;
+  }
 
   cdo_abort("Operator not callable by this name! Name is: %s", operatorName);
 
@@ -113,14 +115,36 @@ Process::get_operator_id()
 }
 
 void
-Process::add_file_in_stream(const std::string &file)
+Process::add_file_in_stream(std::string const &file)
 {
   inputStreams.push_back(std::make_shared<FileStream>(file));
   m_streamCnt++;
 }
 
+#include "memoryStream.h"
 void
-Process::add_file_out_stream(const std::string &file)
+Process::add_mem_in_stream(int ncid)
+{
+  Debug(PROCESS, "adding memory stream with ncid: %d", ncid);
+  inputStreams.push_back(std::make_shared<MemoryStream>(ncid));
+  m_streamCnt++;
+}
+
+void
+Process::add_mem_out_stream(int const &ncid)
+{
+  outputStreams.push_back(std::make_shared<MemoryStream>(ncid));
+  m_streamCnt++;
+}
+void
+Process::add_mem_out_stream(int const &ncid, int const &file_id)
+{
+  outputStreams.push_back(std::make_shared<MemoryStream>(ncid, file_id));
+  m_streamCnt++;
+}
+
+void
+Process::add_file_out_stream(std::string const &file)
 {
   if (file[0] == '-') { cdo_abort("Missing output file. Found an operator instead of filename: %s", file); }
   outputStreams.push_back(std::make_shared<FileStream>(file));
@@ -153,7 +177,6 @@ Process::add_parent(const std::shared_ptr<Process> &parentProcess)
   m_streamCnt++;
 }
 
-
 void *
 execute(void *process)
 {
@@ -198,18 +221,18 @@ Process::start_thread()
   size_t stacksize = 0;
   status = pthread_attr_getstacksize(&attr, &stacksize);
   if (stacksize < 2097152)
-    {
-      stacksize = 2097152;
-      pthread_attr_setstacksize(&attr, stacksize);
-    }
+  {
+    stacksize = 2097152;
+    pthread_attr_setstacksize(&attr, stacksize);
+  }
 
   pthread_t thrID;
   auto rval = pthread_create(&thrID, &attr, execute, this);
   if (rval != 0)
-    {
-      errno = rval;
-      cdo_sys_error("pthread_create failed for '%s'", operatorName);
-    }
+  {
+    errno = rval;
+    cdo_sys_error("pthread_create failed for '%s'", operatorName);
+  }
 
   return thrID;
 }
@@ -219,20 +242,20 @@ Process::start_thread()
 bool
 Process::has_out_stream(CdoStreamID p_streamID)
 {
-  for (const auto &streamID : outputStreams)
-    {
-      if (streamID == p_streamID) return true;
-    }
+  for (auto const &streamID : outputStreams)
+  {
+    if (streamID == p_streamID) return true;
+  }
   return false;
 }
 
 bool
 Process::has_in_stream(CdoStreamID p_streamID)
 {
-  for (const auto &streamID : inputStreams)
-    {
-      if (streamID == p_streamID) return true;
-    }
+  for (auto const &streamID : inputStreams)
+  {
+    if (streamID == p_streamID) return true;
+  }
   return false;
 }
 
@@ -241,10 +264,10 @@ Process::inq_nvals()
 {
   size_t nvals = 0;
   for (size_t i = 0, n = inputStreams.size(); i < n; ++i)
-    {
-      Debug(PROCESS, "Inquiring nvals from instream %s", inputStreams[i]->m_name);
-      nvals += inputStreams[i]->getNvals();
-    }
+  {
+    Debug(PROCESS, "Inquiring nvals from instream %s", inputStreams[i]->m_name);
+    nvals += inputStreams[i]->getNvals();
+  }
   return nvals;
 }
 
@@ -275,13 +298,56 @@ Process::get_argv(int p_idx)
   return m_oargv[p_idx];
 }
 
+std::tuple<int, int>
+Process::create_output()
+{
+  int ncid = -1;
+
+#ifdef HAVE_NETCDF
+  if (auto retVal = nc_create_mem("test_name", 0, 4096, &ncid))
+  {
+    printf("Error: %s\n", nc_strerror(retVal));
+    exit(1);
+  }
+  if (PROCESS) std::cout << "created ncid: " << ncid << std::endl;
+
+  int streamID = streamOpenWriteNCMem(ncid);
+#else
+  int streamID = -100103;
+#endif
+
+  std::stringstream ss = std::stringstream();
+  ss << "ERROR: could not open output stream to memory: errcode: ";
+  ss << std::to_string(streamID);
+  if (streamID < 0) { throw std::runtime_error(ss.str()); }
+  return { ncid, streamID };
+}
+
+CdoStreamID
+Process::open_write(std::string const &p_filename, int filetype)
+{
+  if (filetype == CDI_UNDEFID) filetype = cdo_filetype();
+
+  if (write_mode == ProcessWriteMode::FILEIO) { add_file_out_stream(p_filename); }
+  else if (write_mode == ProcessWriteMode::MEMORY)
+  {
+    auto [fid, sid] = create_output();
+    add_mem_out_stream(fid, sid);
+  }
+
+  const auto pstreamID = outputStreams.back()->open_write(filetype);
+  if (pstreamID == -1) cdo_abort("Could not create pstream for file: %s", p_filename);
+
+  return outputStreams.back();
+}
+
 void
-Process::set_obase(const std::string &obase)
+Process::set_obase(std::string const &obase)
 {
   m_obase = obase;
 }  // TODO into cc
 
-const std::string &
+std::string const &
 Process::get_obase()
 {
   return m_obase;
@@ -303,8 +369,8 @@ Process::get_id()
 void
 Process::cdo_initialize()
 {
-#if defined(_OPENMP)
-  omp_set_num_threads(Threading::ompNumThreads);  // Has to be called for every module (pthread)!
+#ifdef _OPENMP
+  omp_set_num_threads(Threading::ompNumMaxThreads);  // Has to be called for every module (pthread)!
 #endif
 #ifdef HAVE_LIBPTHREAD
   threadID = pthread_self();
